Documentation
¶
Overview ¶
Package securestore provides a small abstraction for secret storage.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrNotFound = errors.New("secure store value not found")
ErrNotFound indicates that a profile has no value for an account key.
Functions ¶
This section is empty.
Types ¶
type KeyringStore ¶
type KeyringStore struct{}
KeyringStore stores values in the operating system keyring.
func (KeyringStore) Delete ¶
func (KeyringStore) Delete(profile, key string) error
type MemoryStore ¶
type MemoryStore struct {
// contains filtered or unexported fields
}
MemoryStore is an in-memory Store intended for deterministic tests.
func NewMemoryStore ¶
func NewMemoryStore() *MemoryStore
NewMemoryStore creates an empty MemoryStore.
func (*MemoryStore) Delete ¶
func (s *MemoryStore) Delete(profile, key string) error
Click to show internal directories.
Click to hide internal directories.